@@ -2,7 +2,7 @@
 """
     MoinMoin - ImprovedTableParser library
 
-    @copyright: 2012, 2013, 2015 by Paul Boddie <paul@boddie.org.uk>
+    @copyright: 2012, 2013, 2015, 2020 by Paul Boddie <paul@boddie.org.uk>
     @license: GNU GPL (v2 or later), see COPYING.txt for details.
 """
 
@@ -10,7 +10,7 @@ from MoinMoin import wikiutil
 from MoinSupport import *
 import re
 
-__version__ = "0.2.1"
+__version__ = "0.2.2"
 
 # Regular expressions.
 
@@ -341,7 +341,7 @@ def to_number(s, request):
     """
 
     if s:
-        return int(get_number(to_plain_text(s, request)))
+        return float(get_number(to_plain_text(s, request)))
     else:
         return s
 
@@ -669,6 +669,12 @@ def formatTable(text, request, fmt, attrs=None, write=None):
             if column_attrs.has_key("rowcontinuation"):
                 del column_attrs["rowcontinuation"]
 
+            # Convert attributes for formatting.
+
+            for key, value in column_attrs.items():
+                if isinstance(value, bool):
+                    column_attrs[key] = value and "true" or "false"
+
             write(fmt.table_cell(1, column_attrs))
 
             if sortable_heading:
